@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
 our $DATE = '2016-10-25'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,11 +33,12 @@ sub _add_category_from_spec {
     my @cats;
     for (@{ $spec->{tags} // [] }) {
         my $tag_name = ref($_) ? $_->{name} : $_;
-        if ($tag_name =~ /^category:(.+)/) {
-            my $cat = ucfirst($1);
+        if ($tag_name =~ /^category(\d+)?:(.+)/) {
+            my $cat = ucfirst($2);
+            my $ordering = $1 // 50;
             $cat =~ s/-/ /g;
             $cat .= " " . $noun;
-            push @cats, [$cat, 50]; # name, ordering
+            push @cats, [$cat, $ordering]; # name, ordering
         }
     }
     if (!@cats) {
@@ -356,7 +357,7 @@ sub gen_cli_doc_data_from_meta {
                     # --help or -v, they are put at the end. so if an argument
                     # option does not have category, we'll put it in the "main"
                     # category.
-                    local $arg_spec->{tags} = ['category:main']
+                    local $arg_spec->{tags} = ['category0:main']
                         if !$arg_spec->{tags} || !@{$arg_spec->{tags}};
                     _add_category_from_spec($clidocdata->{option_categories},
                                             $opt, $arg_spec, "options", 1);
@@ -493,7 +494,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.26 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2016-10-25.
+This document describes version 0.27 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2016-10-25.
 
 =head1 SYNOPSIS
 
@@ -555,10 +556,7 @@ Sample result:
            summary      => "Summary for an example",
          },
        ],
-       option_categories => {
-         "Cat1 options" => { order => 50 },
-         "Main options" => { order => 50 },
-       },
+       option_categories => { "Cat1 options" => { order => 50 }, "Main options" => { order => 0 } },
        opts => {
          "--bool1" => {
            arg         => "bool1",
